@@ -18,7 +18,7 @@ with qw(
 );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010007';
+our $VERSION   = '0.010008';
 
 use Path::Tiny;
 use mro;
@@ -116,25 +116,11 @@ sub _needs_accessors {
 }
 
 sub _mop_metaclass {
-    return 'Moose::Meta::Class';
+    return '$META_CLASS';
 }
 
 sub _mop_attribute_metaclass {
    return 'Moose::Meta::Attribute';
 }
 
-sub _compile_mop_postamble {
-    my ( $self ) = ( shift );
-
-    my $code = '';
-
-    my @superclasses = @{ $self->superclasses || [] }
-        or return $code;
-    $code .= sprintf "Moose::Util::find_meta( %s )->superclasses( %s );\n",
-        B::perlstring( $self->name ),
-        join q{, }, map B::perlstring( $_ ), @superclasses;
-
-    return $code;
-}
-
 1;
