@@ -16,7 +16,7 @@ with qw(
 );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010007';
+our $VERSION   = '0.010008';
 
 use Path::Tiny;
 use B ();
@@ -203,7 +203,7 @@ sub _needs_accessors {
 }
 
 sub _mop_metaclass {
-    return 'Moose::Meta::Role';
+    return '$META_ROLE';
 }
 
 sub _mop_attribute_metaclass {
