@@ -6,7 +6,7 @@ package Mite::Trait::HasRequiredMethods;
 use Mite::Miteception -role, -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010007';
+our $VERSION   = '0.010008';
 
 has required_methods =>
   is            => ro,
@@ -25,12 +25,13 @@ before inject_mite_functions => sub {
     my ( $self, $file, $arg ) = ( shift, @_ );
 
     my $requested = sub { $arg->{$_[0]} ? 1 : $arg->{'!'.$_[0]} ? 0 : $arg->{'-all'} ? 1 : $_[1]; };
+    my $defaults  = ! $arg->{'!-defaults'};
     my $shim      = $self->shim_name;
     my $package   = $self->name;
 
     no strict 'refs';
 
-    if ( $requested->( 'requires', 1 ) ) {
+    if ( $requested->( 'requires', $defaults ) ) {
 
         *{ $package .'::requires' } = sub {
             $self->add_required_methods( @_ );
