@@ -6,7 +6,7 @@ package Mite::Trait::HasRoles;
 use Mite::Miteception -role, -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010007';
+our $VERSION   = '0.010008';
 
 requires qw(
     source
@@ -57,6 +57,7 @@ sub methods_to_import_from_roles {
         __META__
         __FINALIZE_APPLICATION__
         CREATE_CLASS
+        APPLY_TO
     );
 
     return \%methods;
@@ -147,13 +148,14 @@ before inject_mite_functions => sub {
     my ( $self, $file, $arg ) = ( shift, @_ );
 
     my $requested = sub { $arg->{$_[0]} ? 1 : $arg->{'!'.$_[0]} ? 0 : $arg->{'-all'} ? 1 : $_[1]; };
+    my $defaults  = ! $arg->{'!-defaults'};
     my $shim      = $self->shim_name;
     my $package   = $self->name;
     my $fake_ns   = $self->project->can('_module_fakeout_namespace') && $self->project->_module_fakeout_namespace;
 
     no strict 'refs';
 
-    if ( $requested->( 'with', 1 ) ) {
+    if ( $requested->( 'with', $defaults ) ) {
 
         *{ $package .'::with' } = sub {
             return $self->handle_with_keyword(
@@ -223,6 +225,9 @@ sub DOES {
     our %DOES;
     return $DOES{$role} if exists $DOES{$role};
     return 1 if $role eq __PACKAGE__;
+    if ( $INC{'Moose/Util.pm'} and my $meta = Moose::Util::find_meta( ref $self or $self ) ) {
+        $meta->can( 'does_role' ) and $meta->does_role( $role ) and return 1;
+    }
     return $self->SUPER::DOES( $role );
 }
 
@@ -250,4 +255,19 @@ sub _compile_composed_methods {
     return $code;
 }
 
+around _compile_mop_postamble => sub {
+    my ( $next, $self ) = ( shift, shift );
+    my $code = $self->$next( @_ );
+
+    my @roles = @{ $self->roles || [] }
+        or return $code;
+
+    for my $role ( @roles ) {
+        $code .= sprintf "Moose::Util::find_meta( %s )->add_role( Moose::Util::find_meta( %s ) );\n",
+            B::perlstring( $self->name ), B::perlstring( $role->name );
+    }
+
+    return $code;
+};
+
 1;
