@@ -6,7 +6,7 @@ package Mite::Trait::HasSuperclasses;
 use Mite::Miteception -role, -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010007';
+our $VERSION   = '0.010008';
 
 # Super classes as class names
 has extends =>
@@ -128,13 +128,14 @@ before inject_mite_functions => sub {
     my ( $self, $file, $arg ) = ( shift, @_ );
 
     my $requested = sub { $arg->{$_[0]} ? 1 : $arg->{'!'.$_[0]} ? 0 : $arg->{'-all'} ? 1 : $_[1]; };
+    my $defaults  = ! $arg->{'!-defaults'};
     my $shim      = $self->shim_name;
     my $package   = $self->name;
     my $fake_ns   = $self->project->can('_module_fakeout_namespace') && $self->project->_module_fakeout_namespace;
 
     no strict 'refs';
 
-    if ( $requested->( 'extends', 1 ) ) {
+    if ( $requested->( 'extends', $defaults ) ) {
 
         *{ $package .'::extends' } = sub {
             return $self->handle_extends_keyword(
@@ -212,4 +213,17 @@ BEGIN {
 END
 }
 
+around _compile_mop_postamble => sub {
+    my ( $next, $self ) = ( shift, shift );
+    my $code = $self->$next( @_ );
+
+    my @superclasses = @{ $self->superclasses || [] }
+        or return $code;
+    $code .= sprintf "Moose::Util::find_meta( %s )->superclasses( %s );\n",
+        B::perlstring( $self->name ),
+        join q{, }, map B::perlstring( $_ ), @superclasses;
+
+    return $code;
+};
+
 1;
